@@ -24,8 +24,8 @@ show_diff () {
 
 package_name=${PACKAGE_NAME:-sahara_tests}
 # Stash uncommitted changes, checkout master and save coverage report
-uncommited=$(git status --porcelain | grep -v "^??")
-[[ -n $uncommited ]] && git stash > /dev/null
+uncommitted=$(git status --porcelain | grep -v "^??")
+[[ -n $uncommitted ]] && git stash > /dev/null
 git checkout HEAD^
 
 baseline_report=$(mktemp -t sahara-scenario_coverageXXXXXXX)
@@ -35,7 +35,7 @@ baseline_missing=$(awk '/^TOTAL/ { print $3 }' $baseline_report)
 
 # Checkout back and unstash uncommitted changes (if any)
 git checkout -
-[[ -n $uncommited ]] && git stash pop > /dev/null
+[[ -n $uncommitted ]] && git stash pop > /dev/null
 
 # Generate and save coverage report
 current_report=$(mktemp -t sahara-scenario_coverageXXXXXXX)
